==> vaadin-cdi-14.1-20260115.162905-1952-sources.jar: com/vaadin/cdi/annotation/RouteScopeOwner.java <==
/*
 * Copyright 2000-2018 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.vaadin.cdi.annotation;

import com.vaadin.flow.component.HasElement;
import com.vaadin.flow.router.HasErrorParameter;
import com.vaadin.flow.router.Route;
import com.vaadin.flow.router.RouterLayout;

import javax.inject.Qualifier;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.PARAMETER;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Link a {@link RouteScoped @RouteScoped},
 * or {@link NormalRouteScoped @NormalRouteScoped} bean to its owner.
 * <p>
 * Owner is a router component.
 * A {@link Route @Route}, or a {@link RouterLayout}, or a {@link HasErrorParameter}.
 */
@Qualifier
@Retention(RUNTIME)
@Target({TYPE, METHOD, FIELD, PARAMETER})
public @interface RouteScopeOwner {
    /**
     * Owner class of the qualified {@link RouteScoped @RouteScoped},
     * or {@link NormalRouteScoped @NormalRouteScoped} bean.
     * <p>
     * A {@link Route @Route}, or a {@link RouterLayout}, or a {@link HasErrorParameter}
     *
     * @return owner class
     */
    Class<? extends HasElement> value();
}

==> vaadin-cdi-16.0-20260113.084520-728-sources.jar: com/vaadin/cdi/annotation/RouteScopeOwner.java <==
/*
 * Copyright 2000-2018 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.vaadin.cdi.annotation;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import jakarta.inject.Qualifier;

import com.vaadin.flow.component.HasElement;
import com.vaadin.flow.router.HasErrorParameter;
import com.vaadin.flow.router.Route;
import com.vaadin.flow.router.RouterLayout;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.PARAMETER;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Link a {@link RouteScoped @RouteScoped},
 * or {@link NormalRouteScoped @NormalRouteScoped} bean to its owner.
 * <p>
 * Owner is a router component.
 * A {@link Route @Route}, or a {@link RouterLayout}, or a {@link HasErrorParameter}.
 */
@Qualifier
@Retention(RUNTIME)
@Target({TYPE, METHOD, FIELD, PARAMETER})
public @interface RouteScopeOwner {
    /**
     * Owner class of the qualified {@link RouteScoped @RouteScoped},
     * or {@link NormalRouteScoped @NormalRouteScoped} bean.
     * <p>
     * A {@link Route @Route}, or a {@link RouterLayout}, or a {@link HasErrorParameter}
     *
     * @return owner class
     */
    Class<? extends HasElement> value();
}
